@@ -27,7 +27,6 @@
     StringFromCharCode,
     Symbol,
     SymbolFor,
-    SymbolToStringTag,
     WeakMap,
     WeakMapPrototypeGet,
     WeakMapPrototypeSet,
@@ -270,10 +269,6 @@
       return this[_algorithm];
     }
 
-    get [SymbolToStringTag]() {
-      return "CryptoKey";
-    }
-
     [SymbolFor("Deno.customInspect")](inspect) {
       return `${this.constructor.name} ${
         inspect({
@@ -1570,10 +1565,6 @@
 
       return result;
     }
-
-    get [SymbolToStringTag]() {
-      return "SubtleCrypto";
-    }
   }
 
   async function generateKey(normalizedAlgorithm, extractable, usages) {
@@ -2027,6 +2018,7 @@
     }
   }
 
+  webidl.configurePrototype(SubtleCrypto);
   const subtle = webidl.createBranded(SubtleCrypto);
 
   class Crypto {
@@ -2079,10 +2071,6 @@
       return subtle;
     }
 
-    get [SymbolToStringTag]() {
-      return "Crypto";
-    }
-
     [SymbolFor("Deno.customInspect")](inspect) {
       return `${this.constructor.name} ${inspect({})}`;
     }
